# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dropsonde/pb/log.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dropsonde/pb/log.proto',
  package='events',
  syntax='proto2',
  serialized_pb=_b('\n\x16\x64ropsonde/pb/log.proto\x12\x06\x65vents\"\xc5\x01\n\nLogMessage\x12\x0f\n\x07message\x18\x01 \x02(\x0c\x12\x34\n\x0cmessage_type\x18\x02 \x02(\x0e\x32\x1e.events.LogMessage.MessageType\x12\x11\n\ttimestamp\x18\x03 \x02(\x03\x12\x0e\n\x06\x61pp_id\x18\x04 \x01(\t\x12\x13\n\x0bsource_type\x18\x05 \x01(\t\x12\x17\n\x0fsource_instance\x18\x06 \x01(\t\"\x1f\n\x0bMessageType\x12\x07\n\x03OUT\x10\x01\x12\x07\n\x03\x45RR\x10\x02\x42/\n!org.cloudfoundry.dropsonde.eventsB\nLogFactory')
)



_LOGMESSAGE_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='events.LogMessage.MessageType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OUT', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERR', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=201,
  serialized_end=232,
)
_sym_db.RegisterEnumDescriptor(_LOGMESSAGE_MESSAGETYPE)


_LOGMESSAGE = _descriptor.Descriptor(
  name='LogMessage',
  full_name='events.LogMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='events.LogMessage.message', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='events.LogMessage.message_type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='events.LogMessage.timestamp', index=2,
      number=3, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='events.LogMessage.app_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_type', full_name='events.LogMessage.source_type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_instance', full_name='events.LogMessage.source_instance', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOGMESSAGE_MESSAGETYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=35,
  serialized_end=232,
)

_LOGMESSAGE.fields_by_name['message_type'].enum_type = _LOGMESSAGE_MESSAGETYPE
_LOGMESSAGE_MESSAGETYPE.containing_type = _LOGMESSAGE
DESCRIPTOR.message_types_by_name['LogMessage'] = _LOGMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LogMessage = _reflection.GeneratedProtocolMessageType('LogMessage', (_message.Message,), dict(
  DESCRIPTOR = _LOGMESSAGE,
  __module__ = 'dropsonde.pb.log_pb2'
  # @@protoc_insertion_point(class_scope:events.LogMessage)
  ))
_sym_db.RegisterMessage(LogMessage)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n!org.cloudfoundry.dropsonde.eventsB\nLogFactory'))
# @@protoc_insertion_point(module_scope)
